| unifiedml-package | R Documentation |
Provides a unified R6-based interface for various machine learning models with automatic interface detection, consistent cross-validation, model interpretations via numerical derivatives, and visualization. Supports both regression and classification tasks with any model function that follows R's standard modeling conventions (formula or matrix interface).
Index: This package was not yet installed at build time.
T. Moudiki <thierry.moudiki@gmail.com>
T. Moudiki [aut, cre]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.